@@ -1,5 +1,6 @@
 import re
-from typing import Dict, List, Tuple
+from typing import Dict, List, Optional, Tuple
+from mod_ansible_autodoc.markdown.todo import get_todo_source_code_link
 from mod_ansible_autodoc.markdown.parse import (
     get_all_headings,
     parse_section,
@@ -34,8 +35,10 @@ def format_todo(todo: str) -> str:
 
         for todo_item in todo_items:
             # Format current item
+            todo_name = heading.replace(':', '')
+            todo_link = get_todo_source_code_link(todo_name)
             formatted_item = (
-                f"* **{heading.replace(':', '')}:** "
+                f"* **{todo_link}:** "
                 f"{todo_item.lstrip('*').strip('-').strip()}"
             )
             formatted_todo_content.append(formatted_item)
@@ -89,12 +92,21 @@ def format_tags(tags: str) -> str:
     return format_actions(tags)
 
 
-def format_variables(variables: str) -> Tuple[Dict[str, List[List[str]]], str]:
+def format_variables(
+    variables: str,
+    title_prefix: Optional[str] = "#### ",
+    title_postfix: Optional[str] = "",
+    example_comment_prefix: Optional[str] = "### "
+) -> Tuple[Dict[str, List[List[str]]], str]:
     """
     Format variables.
 
     Args:
         variables (str): variables section str
+        title_prefix (str, optional): variable title prefix. Defaults to '#### '
+        title_postfix (str, optional): variable title postfix. Defaults to ''
+        example_comment_prefix (str, optional): variable example comment prefix.
+        Defaults to '### '.
 
     Return:
         (Tuple[Dict[str, List[List[str]]], str]) -> variables json, example str
@@ -119,11 +131,12 @@ def format_variables(variables: str) -> Tuple[Dict[str, List[List[str]]], str]:
         # ... if it does, add hyperlink
         for example in examples:
             if name in example:
-                name = f"[{name}](#{name})"
+                name = f"[`{name}`](#{name})"
 
         # Get value
-        var_item_data = var_item_data[1].split("-")
-        default_value = var_item_data[0].strip().strip("`")
+        var_item_data = var_item_data[1].split("-", 1)
+
+        default_value = var_item_data[0].strip()
 
         # Get description
         description = var_item_data[1].strip()
@@ -133,15 +146,28 @@ def format_variables(variables: str) -> Tuple[Dict[str, List[List[str]]], str]:
 
     variables_json = {"role_variables": formatted_variables}
 
-    return variables_json, format_variable_examples(variables)
+    return (
+        variables_json,
+        format_variable_examples(
+            variables, title_prefix, title_postfix, example_comment_prefix)
+    )
 
 
-def format_variable_examples(variables: str) -> str:
+def format_variable_examples(
+    variables: str,
+    title_prefix: Optional[str] = "#### ",
+    title_postfix: Optional[str] = "",
+    example_comment_prefix: Optional[str] = "###"
+) -> str:
     """
     Format variable examples.
 
     Args:
         variables (str): variables section str
+        title_prefix (str, optional): variable title prefix. Defaults to '#### '
+        title_postfix (str, optional): variable title postfix. Defaults to ''
+        example_comment_prefix (str, optional): variable example comment prefix.
+        Defaults to '### '.
 
     Return:
         (str): formatted examples
@@ -149,6 +175,12 @@ def format_variable_examples(variables: str) -> str:
     if not variables:
         return ""
 
+    if title_prefix is None:
+        title_prefix = "#### "
+
+    if title_postfix is None:
+        title_postfix = ""
+
     # Get examples
     examples = get_examples(variables)
 
@@ -174,22 +206,29 @@ def format_variable_examples(variables: str) -> str:
         # Define which whitespace to use before {items}
 
         # Build heading
-        head = f"#### `{name}`\n\n"
-        comment = f"# Example implementation of the {name} variable"
+        head = f"{title_prefix}`{name}`{title_postfix}\n\n"
+        comment = f"{example_comment_prefix} Example implementation of the " \
+                  f"{name} variable"
+
+        whitespace = "" if items.endswith("\n") else "\n"
 
         formatted_examples.append(
-            f"{head}```yaml\n{comment}\n{name}:{items}\n```")
+            f"{head}```yaml\n{comment}\n{name}:{items}{whitespace}```")
 
     return "\n\n".join(formatted_examples)
 
 
-def reformat_subheaders(content: str) -> str:
+def reformat_subheaders(
+    content: str,
+    change_three_hashes: Optional[bool] = False
+) -> str:
     """
     Reformats subheaders' #s so they all are one header level below the
     preceding header or subheader.
 
     Args:
         content (str): text to reformat
+        change_three_hashes (bool, optional): changes ### to ** **.
 
     Returns:
         str: reformatted text
@@ -224,6 +263,14 @@ def reformat_subheaders(content: str) -> str:
             # the length of the "text" will change, so keep track of the delta
             delta -= match_header_level - len(should_change_to)
 
+    # Change ### subheaders for ** bold text **
+    if change_three_hashes:
+        text_lines = text.split("\n")
+        for i, line in enumerate(text_lines):
+            if line.startswith("### "):
+                text_lines[i] = "\n" + line.replace("### ", "**") + "**\n"
+        text = "\n".join(text_lines)
+
     return text
 
 
